# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/usermeta.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(960, 640)
        Dialog.setMinimumSize(QtCore.QSize(960, 640))
        Dialog.setMaximumSize(QtCore.QSize(960, 640))
        self.tabWidget = QtWidgets.QTabWidget(Dialog)
        self.tabWidget.setGeometry(QtCore.QRect(30, 40, 900, 550))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setTabShape(QtWidgets.QTabWidget.Rounded)
        self.tabWidget.setUsesScrollButtons(True)
        self.tabWidget.setDocumentMode(False)
        self.tabWidget.setTabsClosable(False)
        self.tabWidget.setMovable(False)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_study = QtWidgets.QWidget()
        self.tab_study.setObjectName("tab_study")
        self.identifier = QtWidgets.QLineEdit(self.tab_study)
        self.identifier.setEnabled(False)
        self.identifier.setGeometry(QtCore.QRect(20, 70, 420, 25))
        self.identifier.setStyleSheet("font: italic 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.identifier.setText("")
        self.identifier.setObjectName("identifier")
        self.title = QtWidgets.QLineEdit(self.tab_study)
        self.title.setGeometry(QtCore.QRect(20, 120, 420, 25))
        self.title.setText("")
        self.title.setObjectName("title")
        self.label = QtWidgets.QLabel(self.tab_study)
        self.label.setEnabled(False)
        self.label.setGeometry(QtCore.QRect(20, 50, 131, 16))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.tab_study)
        self.label_2.setGeometry(QtCore.QRect(20, 100, 131, 16))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.tab_study)
        self.label_3.setGeometry(QtCore.QRect(20, 150, 131, 16))
        self.label_3.setObjectName("label_3")
        self.submission_date = QtWidgets.QDateEdit(self.tab_study)
        self.submission_date.setGeometry(QtCore.QRect(20, 170, 201, 25))
        self.submission_date.setCalendarPopup(False)
        self.submission_date.setObjectName("submission_date")
        self.label_4 = QtWidgets.QLabel(self.tab_study)
        self.label_4.setGeometry(QtCore.QRect(250, 150, 131, 16))
        self.label_4.setObjectName("label_4")
        self.release_date = QtWidgets.QDateEdit(self.tab_study)
        self.release_date.setGeometry(QtCore.QRect(239, 170, 201, 25))
        self.release_date.setProperty("showGroupSeparator", False)
        self.release_date.setCalendarPopup(False)
        self.release_date.setDate(QtCore.QDate(2000, 1, 1))
        self.release_date.setObjectName("release_date")
        self.label_5 = QtWidgets.QLabel(self.tab_study)
        self.label_5.setGeometry(QtCore.QRect(20, 20, 261, 31))
        self.label_5.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_5.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_5.setObjectName("label_5")
        self.label_6 = QtWidgets.QLabel(self.tab_study)
        self.label_6.setGeometry(QtCore.QRect(20, 230, 261, 31))
        self.label_6.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_6.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_6.setObjectName("label_6")
        self.pubmed_id = QtWidgets.QLineEdit(self.tab_study)
        self.pubmed_id.setGeometry(QtCore.QRect(20, 280, 131, 25))
        self.pubmed_id.setInputMethodHints(QtCore.Qt.ImhDigitsOnly)
        self.pubmed_id.setObjectName("pubmed_id")
        self.label_7 = QtWidgets.QLabel(self.tab_study)
        self.label_7.setGeometry(QtCore.QRect(20, 260, 131, 16))
        self.label_7.setObjectName("label_7")
        self.doi = QtWidgets.QLineEdit(self.tab_study)
        self.doi.setGeometry(QtCore.QRect(169, 280, 271, 25))
        self.doi.setObjectName("doi")
        self.label_8 = QtWidgets.QLabel(self.tab_study)
        self.label_8.setGeometry(QtCore.QRect(170, 260, 131, 16))
        self.label_8.setObjectName("label_8")
        self.pub_title = QtWidgets.QLineEdit(self.tab_study)
        self.pub_title.setGeometry(QtCore.QRect(20, 330, 420, 25))
        self.pub_title.setText("")
        self.pub_title.setObjectName("pub_title")
        self.label_9 = QtWidgets.QLabel(self.tab_study)
        self.label_9.setGeometry(QtCore.QRect(20, 310, 131, 16))
        self.label_9.setObjectName("label_9")
        self.combo_status = QtWidgets.QComboBox(self.tab_study)
        self.combo_status.setEnabled(False)
        self.combo_status.setGeometry(QtCore.QRect(20, 380, 421, 25))
        self.combo_status.setCurrentText("")
        self.combo_status.setObjectName("combo_status")
        self.label_10 = QtWidgets.QLabel(self.tab_study)
        self.label_10.setGeometry(QtCore.QRect(20, 360, 131, 16))
        self.label_10.setObjectName("label_10")
        self.label_11 = QtWidgets.QLabel(self.tab_study)
        self.label_11.setGeometry(QtCore.QRect(470, 50, 211, 16))
        self.label_11.setObjectName("label_11")
        self.label_12 = QtWidgets.QLabel(self.tab_study)
        self.label_12.setGeometry(QtCore.QRect(470, 230, 261, 31))
        self.label_12.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_12.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_12.setObjectName("label_12")
        self.line = QtWidgets.QFrame(self.tab_study)
        self.line.setGeometry(QtCore.QRect(445, 260, 20, 241))
        self.line.setFrameShape(QtWidgets.QFrame.VLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.label_51 = QtWidgets.QLabel(self.tab_study)
        self.label_51.setGeometry(QtCore.QRect(20, 410, 131, 16))
        self.label_51.setObjectName("label_51")
        self.authors_list = QtWidgets.QTextEdit(self.tab_study)
        self.authors_list.setGeometry(QtCore.QRect(20, 430, 421, 81))
        self.authors_list.setObjectName("authors_list")
        self.status = QtWidgets.QLineEdit(self.tab_study)
        self.status.setGeometry(QtCore.QRect(20, 370, 421, 41))
        self.status.setFrame(False)
        self.status.setObjectName("status")
        self.label_pso = QtWidgets.QLabel(self.tab_study)
        self.label_pso.setGeometry(QtCore.QRect(30, 380, 401, 25))
        self.label_pso.setObjectName("label_pso")
        self.description = QtWidgets.QPlainTextEdit(self.tab_study)
        self.description.setGeometry(QtCore.QRect(470, 70, 401, 121))
        self.description.setObjectName("description")
        self.rm_contact = QtWidgets.QPushButton(self.tab_study)
        self.rm_contact.setGeometry(QtCore.QRect(840, 250, 31, 20))
        self.rm_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.rm_contact.setObjectName("rm_contact")
        self.add_contact = QtWidgets.QPushButton(self.tab_study)
        self.add_contact.setGeometry(QtCore.QRect(800, 250, 31, 21))
        self.add_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.add_contact.setObjectName("add_contact")
        self.edit_contact = QtWidgets.QPushButton(self.tab_study)
        self.edit_contact.setGeometry(QtCore.QRect(760, 250, 31, 20))
        self.edit_contact.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.edit_contact.setObjectName("edit_contact")
        self.table_contacts = QtWidgets.QTableView(self.tab_study)
        self.table_contacts.setGeometry(QtCore.QRect(470, 280, 401, 231))
        self.table_contacts.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table_contacts.setDragDropOverwriteMode(False)
        self.table_contacts.setAlternatingRowColors(True)
        self.table_contacts.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table_contacts.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.table_contacts.setShowGrid(False)
        self.table_contacts.setObjectName("table_contacts")
        self.table_contacts.horizontalHeader().setVisible(False)
        self.table_contacts.horizontalHeader().setCascadingSectionResizes(False)
        self.table_contacts.horizontalHeader().setDefaultSectionSize(0)
        self.table_contacts.horizontalHeader().setHighlightSections(False)
        self.table_contacts.horizontalHeader().setMinimumSectionSize(0)
        self.table_contacts.horizontalHeader().setStretchLastSection(True)
        self.table_contacts.verticalHeader().setVisible(False)
        self.table_contacts.verticalHeader().setDefaultSectionSize(25)
        self.table_contacts.verticalHeader().setHighlightSections(False)
        self.table_contacts.verticalHeader().setMinimumSectionSize(25)
        self.status.raise_()
        self.identifier.raise_()
        self.title.raise_()
        self.label.raise_()
        self.label_2.raise_()
        self.label_3.raise_()
        self.submission_date.raise_()
        self.label_4.raise_()
        self.release_date.raise_()
        self.label_5.raise_()
        self.label_6.raise_()
        self.pubmed_id.raise_()
        self.label_7.raise_()
        self.doi.raise_()
        self.label_8.raise_()
        self.pub_title.raise_()
        self.label_9.raise_()
        self.label_11.raise_()
        self.label_12.raise_()
        self.line.raise_()
        self.label_51.raise_()
        self.authors_list.raise_()
        self.combo_status.raise_()
        self.label_10.raise_()
        self.label_pso.raise_()
        self.description.raise_()
        self.rm_contact.raise_()
        self.add_contact.raise_()
        self.edit_contact.raise_()
        self.table_contacts.raise_()
        self.tabWidget.addTab(self.tab_study, "")
        self.tab_investigation = QtWidgets.QWidget()
        self.tab_investigation.setObjectName("tab_investigation")
        self.label_19 = QtWidgets.QLabel(self.tab_investigation)
        self.label_19.setGeometry(QtCore.QRect(20, 150, 131, 16))
        self.label_19.setObjectName("label_19")
        self.submission_date_2 = QtWidgets.QDateEdit(self.tab_investigation)
        self.submission_date_2.setGeometry(QtCore.QRect(20, 170, 201, 25))
        self.submission_date_2.setCalendarPopup(False)
        self.submission_date_2.setObjectName("submission_date_2")
        self.release_date_2 = QtWidgets.QDateEdit(self.tab_investigation)
        self.release_date_2.setGeometry(QtCore.QRect(239, 170, 201, 25))
        self.release_date_2.setCalendarPopup(False)
        self.release_date_2.setObjectName("release_date_2")
        self.label_24 = QtWidgets.QLabel(self.tab_investigation)
        self.label_24.setGeometry(QtCore.QRect(470, 50, 211, 16))
        self.label_24.setObjectName("label_24")
        self.label_25 = QtWidgets.QLabel(self.tab_investigation)
        self.label_25.setGeometry(QtCore.QRect(20, 20, 261, 21))
        self.label_25.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_25.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_25.setObjectName("label_25")
        self.identifier_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.identifier_2.setEnabled(False)
        self.identifier_2.setGeometry(QtCore.QRect(20, 70, 420, 25))
        self.identifier_2.setStyleSheet("font: italic 10pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.identifier_2.setText("")
        self.identifier_2.setObjectName("identifier_2")
        self.label_26 = QtWidgets.QLabel(self.tab_investigation)
        self.label_26.setGeometry(QtCore.QRect(250, 150, 131, 16))
        self.label_26.setObjectName("label_26")
        self.label_27 = QtWidgets.QLabel(self.tab_investigation)
        self.label_27.setEnabled(False)
        self.label_27.setGeometry(QtCore.QRect(20, 50, 131, 16))
        self.label_27.setObjectName("label_27")
        self.title_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.title_2.setEnabled(False)
        self.title_2.setGeometry(QtCore.QRect(20, 120, 420, 25))
        self.title_2.setObjectName("title_2")
        self.label_28 = QtWidgets.QLabel(self.tab_investigation)
        self.label_28.setGeometry(QtCore.QRect(20, 100, 131, 16))
        self.label_28.setObjectName("label_28")
        self.label_29 = QtWidgets.QLabel(self.tab_investigation)
        self.label_29.setGeometry(QtCore.QRect(470, 230, 261, 31))
        self.label_29.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_29.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_29.setObjectName("label_29")
        self.pubmed_id_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.pubmed_id_2.setGeometry(QtCore.QRect(20, 280, 131, 25))
        self.pubmed_id_2.setObjectName("pubmed_id_2")
        self.line_2 = QtWidgets.QFrame(self.tab_investigation)
        self.line_2.setGeometry(QtCore.QRect(445, 260, 20, 251))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.combo_status_2 = QtWidgets.QComboBox(self.tab_investigation)
        self.combo_status_2.setEnabled(False)
        self.combo_status_2.setGeometry(QtCore.QRect(20, 380, 421, 25))
        self.combo_status_2.setCurrentText("")
        self.combo_status_2.setMaxVisibleItems(10)
        self.combo_status_2.setObjectName("combo_status_2")
        self.label_32 = QtWidgets.QLabel(self.tab_investigation)
        self.label_32.setGeometry(QtCore.QRect(20, 360, 131, 16))
        self.label_32.setObjectName("label_32")
        self.label_33 = QtWidgets.QLabel(self.tab_investigation)
        self.label_33.setGeometry(QtCore.QRect(20, 230, 261, 21))
        self.label_33.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_33.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_33.setObjectName("label_33")
        self.label_36 = QtWidgets.QLabel(self.tab_investigation)
        self.label_36.setGeometry(QtCore.QRect(20, 260, 131, 16))
        self.label_36.setObjectName("label_36")
        self.doi_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.doi_2.setGeometry(QtCore.QRect(169, 280, 271, 25))
        self.doi_2.setObjectName("doi_2")
        self.pub_title_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.pub_title_2.setGeometry(QtCore.QRect(20, 330, 420, 25))
        self.pub_title_2.setText("")
        self.pub_title_2.setObjectName("pub_title_2")
        self.label_39 = QtWidgets.QLabel(self.tab_investigation)
        self.label_39.setGeometry(QtCore.QRect(20, 310, 131, 16))
        self.label_39.setObjectName("label_39")
        self.label_43 = QtWidgets.QLabel(self.tab_investigation)
        self.label_43.setGeometry(QtCore.QRect(170, 260, 131, 16))
        self.label_43.setObjectName("label_43")
        self.label_52 = QtWidgets.QLabel(self.tab_investigation)
        self.label_52.setGeometry(QtCore.QRect(20, 410, 131, 16))
        self.label_52.setObjectName("label_52")
        self.authors_list_2 = QtWidgets.QTextEdit(self.tab_investigation)
        self.authors_list_2.setEnabled(True)
        self.authors_list_2.setGeometry(QtCore.QRect(20, 430, 421, 81))
        self.authors_list_2.setStyleSheet("")
        self.authors_list_2.setObjectName("authors_list_2")
        self.status_2 = QtWidgets.QLineEdit(self.tab_investigation)
        self.status_2.setGeometry(QtCore.QRect(20, 370, 421, 41))
        self.status_2.setFrame(False)
        self.status_2.setObjectName("status_2")
        self.label_pso_2 = QtWidgets.QLabel(self.tab_investigation)
        self.label_pso_2.setGeometry(QtCore.QRect(30, 380, 401, 25))
        self.label_pso_2.setObjectName("label_pso_2")
        self.description_2 = QtWidgets.QPlainTextEdit(self.tab_investigation)
        self.description_2.setGeometry(QtCore.QRect(470, 70, 401, 121))
        self.description_2.setObjectName("description_2")
        self.add_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.add_contact_2.setGeometry(QtCore.QRect(800, 250, 31, 20))
        self.add_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.add_contact_2.setObjectName("add_contact_2")
        self.table_contacts_2 = QtWidgets.QTableView(self.tab_investigation)
        self.table_contacts_2.setGeometry(QtCore.QRect(470, 280, 401, 231))
        self.table_contacts_2.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.table_contacts_2.setDragDropOverwriteMode(False)
        self.table_contacts_2.setAlternatingRowColors(True)
        self.table_contacts_2.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.table_contacts_2.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectRows)
        self.table_contacts_2.setShowGrid(False)
        self.table_contacts_2.setObjectName("table_contacts_2")
        self.table_contacts_2.horizontalHeader().setVisible(False)
        self.table_contacts_2.horizontalHeader().setCascadingSectionResizes(False)
        self.table_contacts_2.horizontalHeader().setDefaultSectionSize(0)
        self.table_contacts_2.horizontalHeader().setHighlightSections(False)
        self.table_contacts_2.horizontalHeader().setMinimumSectionSize(0)
        self.table_contacts_2.horizontalHeader().setStretchLastSection(True)
        self.table_contacts_2.verticalHeader().setVisible(False)
        self.table_contacts_2.verticalHeader().setDefaultSectionSize(25)
        self.table_contacts_2.verticalHeader().setHighlightSections(False)
        self.table_contacts_2.verticalHeader().setMinimumSectionSize(25)
        self.rm_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.rm_contact_2.setGeometry(QtCore.QRect(840, 250, 31, 20))
        self.rm_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.rm_contact_2.setObjectName("rm_contact_2")
        self.edit_contact_2 = QtWidgets.QPushButton(self.tab_investigation)
        self.edit_contact_2.setGeometry(QtCore.QRect(760, 250, 31, 20))
        self.edit_contact_2.setStyleSheet("font: 9pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.edit_contact_2.setObjectName("edit_contact_2")
        self.status_2.raise_()
        self.label_19.raise_()
        self.submission_date_2.raise_()
        self.release_date_2.raise_()
        self.label_24.raise_()
        self.label_25.raise_()
        self.identifier_2.raise_()
        self.label_26.raise_()
        self.label_27.raise_()
        self.title_2.raise_()
        self.label_28.raise_()
        self.label_29.raise_()
        self.pubmed_id_2.raise_()
        self.line_2.raise_()
        self.combo_status_2.raise_()
        self.label_32.raise_()
        self.label_33.raise_()
        self.label_36.raise_()
        self.doi_2.raise_()
        self.pub_title_2.raise_()
        self.label_39.raise_()
        self.label_43.raise_()
        self.label_52.raise_()
        self.authors_list_2.raise_()
        self.label_pso_2.raise_()
        self.description_2.raise_()
        self.add_contact_2.raise_()
        self.table_contacts_2.raise_()
        self.rm_contact_2.raise_()
        self.edit_contact_2.raise_()
        self.tabWidget.addTab(self.tab_investigation, "")
        self.tab_misc = QtWidgets.QWidget()
        self.tab_misc.setEnabled(True)
        self.tab_misc.setObjectName("tab_misc")
        self.label_44 = QtWidgets.QLabel(self.tab_misc)
        self.label_44.setGeometry(QtCore.QRect(20, 20, 261, 16))
        self.label_44.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_44.setObjectName("label_44")
        self.label_45 = QtWidgets.QLabel(self.tab_misc)
        self.label_45.setGeometry(QtCore.QRect(20, 50, 70, 55))
        self.label_45.setAlignment(QtCore.Qt.AlignCenter)
        self.label_45.setObjectName("label_45")
        self.name_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism.setEnabled(True)
        self.name_organism.setGeometry(QtCore.QRect(160, 50, 610, 25))
        self.name_organism.setText("")
        self.name_organism.setObjectName("name_organism")
        self.label_46 = QtWidgets.QLabel(self.tab_misc)
        self.label_46.setGeometry(QtCore.QRect(20, 115, 70, 55))
        self.label_46.setAlignment(QtCore.Qt.AlignCenter)
        self.label_46.setWordWrap(True)
        self.label_46.setObjectName("label_46")
        self.name_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism_variant.setEnabled(True)
        self.name_organism_variant.setGeometry(QtCore.QRect(159, 115, 611, 25))
        self.name_organism_variant.setText("")
        self.name_organism_variant.setObjectName("name_organism_variant")
        self.name_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.name_organism_part.setEnabled(True)
        self.name_organism_part.setGeometry(QtCore.QRect(159, 180, 611, 25))
        self.name_organism_part.setText("")
        self.name_organism_part.setObjectName("name_organism_part")
        self.label_47 = QtWidgets.QLabel(self.tab_misc)
        self.label_47.setGeometry(QtCore.QRect(20, 180, 70, 55))
        self.label_47.setAlignment(QtCore.Qt.AlignCenter)
        self.label_47.setWordWrap(True)
        self.label_47.setObjectName("label_47")
        self.label_50 = QtWidgets.QLabel(self.tab_misc)
        self.label_50.setGeometry(QtCore.QRect(20, 250, 261, 31))
        self.label_50.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_50.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.label_50.setObjectName("label_50")
        self.tabWidget_2 = QtWidgets.QTabWidget(self.tab_misc)
        self.tabWidget_2.setGeometry(QtCore.QRect(17, 290, 860, 211))
        self.tabWidget_2.setUsesScrollButtons(False)
        self.tabWidget_2.setObjectName("tabWidget_2")
        self.extraction = QtWidgets.QWidget()
        self.extraction.setObjectName("extraction")
        self.extraction_desc = QtWidgets.QPlainTextEdit(self.extraction)
        self.extraction_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.extraction_desc.setObjectName("extraction_desc")
        self.tabWidget_2.addTab(self.extraction, "")
        self.nmr_sample = QtWidgets.QWidget()
        self.nmr_sample.setObjectName("nmr_sample")
        self.nmr_sample_desc = QtWidgets.QPlainTextEdit(self.nmr_sample)
        self.nmr_sample_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_sample_desc.setObjectName("nmr_sample_desc")
        self.tabWidget_2.addTab(self.nmr_sample, "")
        self.nmr_spec = QtWidgets.QWidget()
        self.nmr_spec.setObjectName("nmr_spec")
        self.nmr_spec_desc = QtWidgets.QPlainTextEdit(self.nmr_spec)
        self.nmr_spec_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_spec_desc.setObjectName("nmr_spec_desc")
        self.tabWidget_2.addTab(self.nmr_spec, "")
        self.nmr_assay = QtWidgets.QWidget()
        self.nmr_assay.setObjectName("nmr_assay")
        self.nmr_assay_desc = QtWidgets.QPlainTextEdit(self.nmr_assay)
        self.nmr_assay_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.nmr_assay_desc.setObjectName("nmr_assay_desc")
        self.tabWidget_2.addTab(self.nmr_assay, "")
        self.data_trans = QtWidgets.QWidget()
        self.data_trans.setObjectName("data_trans")
        self.data_trans_desc = QtWidgets.QPlainTextEdit(self.data_trans)
        self.data_trans_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.data_trans_desc.setObjectName("data_trans_desc")
        self.tabWidget_2.addTab(self.data_trans, "")
        self.metabo_id = QtWidgets.QWidget()
        self.metabo_id.setObjectName("metabo_id")
        self.metabo_id_desc = QtWidgets.QPlainTextEdit(self.metabo_id)
        self.metabo_id_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.metabo_id_desc.setObjectName("metabo_id_desc")
        self.tabWidget_2.addTab(self.metabo_id, "")
        self.sample_collec = QtWidgets.QWidget()
        self.sample_collec.setObjectName("sample_collec")
        self.sample_collec_desc = QtWidgets.QPlainTextEdit(self.sample_collec)
        self.sample_collec_desc.setGeometry(QtCore.QRect(0, 0, 847, 180))
        self.sample_collec_desc.setObjectName("sample_collec_desc")
        self.tabWidget_2.addTab(self.sample_collec, "")
        self.search_organism = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism.setGeometry(QtCore.QRect(780, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism.setFont(font)
        self.search_organism.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism.setObjectName("search_organism")
        self.search_organism_variant = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism_variant.setGeometry(QtCore.QRect(780, 115, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism_variant.setFont(font)
        self.search_organism_variant.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism_variant.setObjectName("search_organism_variant")
        self.search_organism_part = QtWidgets.QPushButton(self.tab_misc)
        self.search_organism_part.setGeometry(QtCore.QRect(780, 180, 40, 50))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_organism_part.setFont(font)
        self.search_organism_part.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_organism_part.setObjectName("search_organism_part")
        self.accession_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism.setEnabled(True)
        self.accession_organism.setGeometry(QtCore.QRect(399, 75, 371, 25))
        self.accession_organism.setText("")
        self.accession_organism.setObjectName("accession_organism")
        self.accession_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism_variant.setEnabled(True)
        self.accession_organism_variant.setGeometry(QtCore.QRect(399, 140, 371, 25))
        self.accession_organism_variant.setStyleSheet("")
        self.accession_organism_variant.setText("")
        self.accession_organism_variant.setObjectName("accession_organism_variant")
        self.accession_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.accession_organism_part.setEnabled(True)
        self.accession_organism_part.setGeometry(QtCore.QRect(399, 205, 371, 25))
        self.accession_organism_part.setText("")
        self.accession_organism_part.setObjectName("accession_organism_part")
        self.ref_organism_part = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism_part.setEnabled(True)
        self.ref_organism_part.setGeometry(QtCore.QRect(160, 205, 205, 25))
        self.ref_organism_part.setObjectName("ref_organism_part")
        self.ref_organism_variant = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism_variant.setEnabled(True)
        self.ref_organism_variant.setGeometry(QtCore.QRect(160, 140, 205, 25))
        self.ref_organism_variant.setObjectName("ref_organism_variant")
        self.ref_organism = QtWidgets.QLineEdit(self.tab_misc)
        self.ref_organism.setEnabled(True)
        self.ref_organism.setGeometry(QtCore.QRect(160, 75, 205, 25))
        self.ref_organism.setObjectName("ref_organism")
        self.rm_organism = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism.setGeometry(QtCore.QRect(830, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism.setFont(font)
        self.rm_organism.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism.setObjectName("rm_organism")
        self.rm_organism_variant = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism_variant.setGeometry(QtCore.QRect(830, 115, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism_variant.setFont(font)
        self.rm_organism_variant.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism_variant.setObjectName("rm_organism_variant")
        self.rm_organism_part = QtWidgets.QPushButton(self.tab_misc)
        self.rm_organism_part.setGeometry(QtCore.QRect(830, 180, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_organism_part.setFont(font)
        self.rm_organism_part.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_organism_part.setObjectName("rm_organism_part")
        self.label_59 = QtWidgets.QLabel(self.tab_misc)
        self.label_59.setGeometry(QtCore.QRect(90, 50, 64, 25))
        self.label_59.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_59.setObjectName("label_59")
        self.label_60 = QtWidgets.QLabel(self.tab_misc)
        self.label_60.setGeometry(QtCore.QRect(90, 75, 64, 25))
        self.label_60.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_60.setObjectName("label_60")
        self.label_61 = QtWidgets.QLabel(self.tab_misc)
        self.label_61.setGeometry(QtCore.QRect(370, 80, 64, 15))
        self.label_61.setObjectName("label_61")
        self.label_62 = QtWidgets.QLabel(self.tab_misc)
        self.label_62.setGeometry(QtCore.QRect(370, 140, 64, 25))
        self.label_62.setObjectName("label_62")
        self.label_63 = QtWidgets.QLabel(self.tab_misc)
        self.label_63.setGeometry(QtCore.QRect(370, 210, 64, 15))
        self.label_63.setObjectName("label_63")
        self.label_64 = QtWidgets.QLabel(self.tab_misc)
        self.label_64.setGeometry(QtCore.QRect(90, 115, 64, 25))
        self.label_64.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_64.setObjectName("label_64")
        self.label_65 = QtWidgets.QLabel(self.tab_misc)
        self.label_65.setGeometry(QtCore.QRect(90, 140, 64, 25))
        self.label_65.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_65.setObjectName("label_65")
        self.label_66 = QtWidgets.QLabel(self.tab_misc)
        self.label_66.setGeometry(QtCore.QRect(90, 180, 64, 25))
        self.label_66.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_66.setObjectName("label_66")
        self.label_67 = QtWidgets.QLabel(self.tab_misc)
        self.label_67.setGeometry(QtCore.QRect(90, 206, 64, 25))
        self.label_67.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_67.setObjectName("label_67")
        self.tabWidget.addTab(self.tab_misc, "")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.label_70 = QtWidgets.QLabel(self.tab)
        self.label_70.setGeometry(QtCore.QRect(370, 190, 64, 15))
        self.label_70.setObjectName("label_70")
        self.label_68 = QtWidgets.QLabel(self.tab)
        self.label_68.setGeometry(QtCore.QRect(90, 160, 64, 25))
        self.label_68.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_68.setObjectName("label_68")
        self.ref_solvent = QtWidgets.QLineEdit(self.tab)
        self.ref_solvent.setEnabled(True)
        self.ref_solvent.setGeometry(QtCore.QRect(160, 185, 205, 25))
        self.ref_solvent.setObjectName("ref_solvent")
        self.search_solvent = QtWidgets.QPushButton(self.tab)
        self.search_solvent.setGeometry(QtCore.QRect(780, 160, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_solvent.setFont(font)
        self.search_solvent.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_solvent.setObjectName("search_solvent")
        self.accession_solvent = QtWidgets.QLineEdit(self.tab)
        self.accession_solvent.setEnabled(True)
        self.accession_solvent.setGeometry(QtCore.QRect(399, 185, 371, 25))
        self.accession_solvent.setText("")
        self.accession_solvent.setObjectName("accession_solvent")
        self.label_48 = QtWidgets.QLabel(self.tab)
        self.label_48.setGeometry(QtCore.QRect(20, 160, 70, 55))
        self.label_48.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_48.setWordWrap(True)
        self.label_48.setObjectName("label_48")
        self.rm_solvent = QtWidgets.QPushButton(self.tab)
        self.rm_solvent.setGeometry(QtCore.QRect(830, 160, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_solvent.setFont(font)
        self.rm_solvent.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_solvent.setObjectName("rm_solvent")
        self.name_solvent = QtWidgets.QLineEdit(self.tab)
        self.name_solvent.setEnabled(True)
        self.name_solvent.setGeometry(QtCore.QRect(160, 160, 610, 25))
        self.name_solvent.setText("")
        self.name_solvent.setObjectName("name_solvent")
        self.label_69 = QtWidgets.QLabel(self.tab)
        self.label_69.setGeometry(QtCore.QRect(90, 185, 64, 25))
        self.label_69.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_69.setObjectName("label_69")
        self.label_49 = QtWidgets.QLabel(self.tab)
        self.label_49.setGeometry(QtCore.QRect(20, 130, 261, 16))
        self.label_49.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_49.setObjectName("label_49")
        self.label_53 = QtWidgets.QLabel(self.tab)
        self.label_53.setGeometry(QtCore.QRect(20, 225, 91, 55))
        self.label_53.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_53.setWordWrap(True)
        self.label_53.setObjectName("label_53")
        self.label_57 = QtWidgets.QLabel(self.tab)
        self.label_57.setGeometry(QtCore.QRect(20, 310, 261, 16))
        self.label_57.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_57.setObjectName("label_57")
        self.label_58 = QtWidgets.QLabel(self.tab)
        self.label_58.setGeometry(QtCore.QRect(20, 330, 91, 55))
        self.label_58.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_58.setWordWrap(True)
        self.label_58.setObjectName("label_58")
        self.ref_label = QtWidgets.QLineEdit(self.tab)
        self.ref_label.setEnabled(True)
        self.ref_label.setGeometry(QtCore.QRect(160, 355, 205, 25))
        self.ref_label.setObjectName("ref_label")
        self.accession_label = QtWidgets.QLineEdit(self.tab)
        self.accession_label.setEnabled(True)
        self.accession_label.setGeometry(QtCore.QRect(399, 355, 371, 25))
        self.accession_label.setText("")
        self.accession_label.setObjectName("accession_label")
        self.rm_label = QtWidgets.QPushButton(self.tab)
        self.rm_label.setGeometry(QtCore.QRect(830, 330, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_label.setFont(font)
        self.rm_label.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_label.setObjectName("rm_label")
        self.label_74 = QtWidgets.QLabel(self.tab)
        self.label_74.setGeometry(QtCore.QRect(370, 360, 64, 15))
        self.label_74.setObjectName("label_74")
        self.label_75 = QtWidgets.QLabel(self.tab)
        self.label_75.setGeometry(QtCore.QRect(90, 335, 64, 25))
        self.label_75.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_75.setObjectName("label_75")
        self.label_76 = QtWidgets.QLabel(self.tab)
        self.label_76.setGeometry(QtCore.QRect(90, 355, 64, 25))
        self.label_76.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_76.setObjectName("label_76")
        self.name_label = QtWidgets.QLineEdit(self.tab)
        self.name_label.setEnabled(True)
        self.name_label.setGeometry(QtCore.QRect(160, 330, 610, 25))
        self.name_label.setText("")
        self.name_label.setObjectName("name_label")
        self.search_label = QtWidgets.QPushButton(self.tab)
        self.search_label.setGeometry(QtCore.QRect(780, 330, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_label.setFont(font)
        self.search_label.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_label.setObjectName("search_label")
        self.label_54 = QtWidgets.QLabel(self.tab)
        self.label_54.setGeometry(QtCore.QRect(20, 20, 261, 16))
        self.label_54.setStyleSheet("font: 12pt url(:/fonts/assets/fonts/Verdana.ttf);")
        self.label_54.setObjectName("label_54")
        self.accession_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.accession_extraction_method.setEnabled(True)
        self.accession_extraction_method.setGeometry(QtCore.QRect(399, 75, 371, 25))
        self.accession_extraction_method.setText("")
        self.accession_extraction_method.setObjectName("accession_extraction_method")
        self.label_55 = QtWidgets.QLabel(self.tab)
        self.label_55.setGeometry(QtCore.QRect(20, 44, 81, 61))
        self.label_55.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_55.setWordWrap(True)
        self.label_55.setObjectName("label_55")
        self.rm_extraction_method = QtWidgets.QPushButton(self.tab)
        self.rm_extraction_method.setGeometry(QtCore.QRect(830, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Functional")
        font.setPointSize(12)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.rm_extraction_method.setFont(font)
        self.rm_extraction_method.setStyleSheet("font: 12pt \":/fonts/assets/fonts/EBI-Functional.ttf\";\n"
"font-family: \"EBI-Functional\";")
        self.rm_extraction_method.setObjectName("rm_extraction_method")
        self.label_77 = QtWidgets.QLabel(self.tab)
        self.label_77.setGeometry(QtCore.QRect(90, 75, 64, 25))
        self.label_77.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_77.setObjectName("label_77")
        self.label_78 = QtWidgets.QLabel(self.tab)
        self.label_78.setGeometry(QtCore.QRect(370, 80, 64, 15))
        self.label_78.setObjectName("label_78")
        self.search_extraction_method = QtWidgets.QPushButton(self.tab)
        self.search_extraction_method.setGeometry(QtCore.QRect(780, 50, 40, 51))
        font = QtGui.QFont()
        font.setFamily("EBI-Conceptual")
        font.setPointSize(14)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.search_extraction_method.setFont(font)
        self.search_extraction_method.setStyleSheet("font: 14pt \":/fonts/assets/fonts/EBI-Conceptual.ttf\";\n"
"font-family: \"EBI-Conceptual\";")
        self.search_extraction_method.setObjectName("search_extraction_method")
        self.ref_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.ref_extraction_method.setEnabled(True)
        self.ref_extraction_method.setGeometry(QtCore.QRect(160, 75, 205, 25))
        self.ref_extraction_method.setObjectName("ref_extraction_method")
        self.label_79 = QtWidgets.QLabel(self.tab)
        self.label_79.setGeometry(QtCore.QRect(90, 50, 64, 25))
        self.label_79.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_79.setObjectName("label_79")
        self.name_extraction_method = QtWidgets.QLineEdit(self.tab)
        self.name_extraction_method.setEnabled(True)
        self.name_extraction_method.setGeometry(QtCore.QRect(160, 50, 610, 25))
        self.name_extraction_method.setText("")
        self.name_extraction_method.setObjectName("name_extraction_method")
        self.label_56 = QtWidgets.QLabel(self.tab)
        self.label_56.setGeometry(QtCore.QRect(10, 460, 311, 55))
        self.label_56.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.label_56.setWordWrap(True)
        self.label_56.setObjectName("label_56")
        self.value_sample_pH = QtWidgets.QLineEdit(self.tab)
        self.value_sample_pH.setGeometry(QtCore.QRect(160, 240, 201, 25))
        self.value_sample_pH.setObjectName("value_sample_pH")
        self.label_71 = QtWidgets.QLabel(self.tab)
        self.label_71.setGeometry(QtCore.QRect(90, 240, 64, 25))
        self.label_71.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_71.setObjectName("label_71")
        self.tabWidget.addTab(self.tab, "")
        self.frame = QtWidgets.QFrame(Dialog)
        self.frame.setGeometry(QtCore.QRect(0, 0, 960, 30))
        self.frame.setStyleSheet("background: rgb(255, 255, 255)rgb(11, 123, 189);")
        self.frame.setFrameShape(QtWidgets.QFrame.Box)
        self.frame.setFrameShadow(QtWidgets.QFrame.Plain)
        self.frame.setObjectName("frame")
        self.label_22 = QtWidgets.QLabel(Dialog)
        self.label_22.setGeometry(QtCore.QRect(30, 610, 311, 16))
        self.label_22.setObjectName("label_22")
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(440, 606, 491, 26))
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Apply|QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")

        self.retranslateUi(Dialog)
        self.tabWidget.setCurrentIndex(0)
        self.combo_status_2.setCurrentIndex(-1)
        self.tabWidget_2.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Dialog)
        Dialog.setTabOrder(self.identifier, self.title)
        Dialog.setTabOrder(self.title, self.submission_date)
        Dialog.setTabOrder(self.submission_date, self.release_date)
        Dialog.setTabOrder(self.release_date, self.description)
        Dialog.setTabOrder(self.description, self.pubmed_id)
        Dialog.setTabOrder(self.pubmed_id, self.doi)
        Dialog.setTabOrder(self.doi, self.pub_title)
        Dialog.setTabOrder(self.pub_title, self.combo_status)
        Dialog.setTabOrder(self.combo_status, self.authors_list)
        Dialog.setTabOrder(self.authors_list, self.table_contacts)
        Dialog.setTabOrder(self.table_contacts, self.edit_contact)
        Dialog.setTabOrder(self.edit_contact, self.add_contact)
        Dialog.setTabOrder(self.add_contact, self.rm_contact)
        Dialog.setTabOrder(self.rm_contact, self.identifier_2)
        Dialog.setTabOrder(self.identifier_2, self.title_2)
        Dialog.setTabOrder(self.title_2, self.submission_date_2)
        Dialog.setTabOrder(self.submission_date_2, self.release_date_2)
        Dialog.setTabOrder(self.release_date_2, self.description_2)
        Dialog.setTabOrder(self.description_2, self.pubmed_id_2)
        Dialog.setTabOrder(self.pubmed_id_2, self.doi_2)
        Dialog.setTabOrder(self.doi_2, self.pub_title_2)
        Dialog.setTabOrder(self.pub_title_2, self.combo_status_2)
        Dialog.setTabOrder(self.combo_status_2, self.authors_list_2)
        Dialog.setTabOrder(self.authors_list_2, self.table_contacts_2)
        Dialog.setTabOrder(self.table_contacts_2, self.edit_contact_2)
        Dialog.setTabOrder(self.edit_contact_2, self.add_contact_2)
        Dialog.setTabOrder(self.add_contact_2, self.rm_contact_2)
        Dialog.setTabOrder(self.rm_contact_2, self.name_organism)
        Dialog.setTabOrder(self.name_organism, self.ref_organism)
        Dialog.setTabOrder(self.ref_organism, self.accession_organism)
        Dialog.setTabOrder(self.accession_organism, self.search_organism)
        Dialog.setTabOrder(self.search_organism, self.rm_organism)
        Dialog.setTabOrder(self.rm_organism, self.name_organism_variant)
        Dialog.setTabOrder(self.name_organism_variant, self.ref_organism_variant)
        Dialog.setTabOrder(self.ref_organism_variant, self.accession_organism_variant)
        Dialog.setTabOrder(self.accession_organism_variant, self.search_organism_variant)
        Dialog.setTabOrder(self.search_organism_variant, self.rm_organism_variant)
        Dialog.setTabOrder(self.rm_organism_variant, self.name_organism_part)
        Dialog.setTabOrder(self.name_organism_part, self.ref_organism_part)
        Dialog.setTabOrder(self.ref_organism_part, self.accession_organism_part)
        Dialog.setTabOrder(self.accession_organism_part, self.search_organism_part)
        Dialog.setTabOrder(self.search_organism_part, self.rm_organism_part)
        Dialog.setTabOrder(self.rm_organism_part, self.extraction_desc)
        Dialog.setTabOrder(self.extraction_desc, self.nmr_sample_desc)
        Dialog.setTabOrder(self.nmr_sample_desc, self.nmr_spec_desc)
        Dialog.setTabOrder(self.nmr_spec_desc, self.data_trans_desc)
        Dialog.setTabOrder(self.data_trans_desc, self.metabo_id_desc)
        Dialog.setTabOrder(self.metabo_id_desc, self.tabWidget)
        Dialog.setTabOrder(self.tabWidget, self.tabWidget_2)
        Dialog.setTabOrder(self.tabWidget_2, self.status)
        Dialog.setTabOrder(self.status, self.status_2)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Additional Metadata"))
        self.identifier.setPlaceholderText(_translate("Dialog", "will use study identifier name from main window"))
        self.label.setText(_translate("Dialog", "Identifier"))
        self.label_2.setText(_translate("Dialog", "Title *"))
        self.label_3.setText(_translate("Dialog", "Submission date"))
        self.submission_date.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_4.setText(_translate("Dialog", "Release date"))
        self.release_date.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_5.setText(_translate("Dialog", "Study"))
        self.label_6.setText(_translate("Dialog", "Study Publication"))
        self.pubmed_id.setPlaceholderText(_translate("Dialog", "e.g. 26496010"))
        self.label_7.setText(_translate("Dialog", "PubMed identifier"))
        self.doi.setPlaceholderText(_translate("Dialog", "e.g.  10.1016/j.jhep.2013.12.002"))
        self.label_8.setText(_translate("Dialog", "DOI"))
        self.label_9.setText(_translate("Dialog", "Title"))
        self.label_10.setText(_translate("Dialog", "Status"))
        self.label_11.setText(_translate("Dialog", "Description *"))
        self.label_12.setText(_translate("Dialog", "Study Contacts *"))
        self.label_51.setText(_translate("Dialog", "Authors"))
        self.label_pso.setText(_translate("Dialog", "connecting to PSO <sparontologies.net/ontologies/pso>"))
        self.rm_contact.setText(_translate("Dialog", "-"))
        self.add_contact.setText(_translate("Dialog", "+"))
        self.edit_contact.setText(_translate("Dialog", "e"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_study), _translate("Dialog", "Study"))
        self.label_19.setText(_translate("Dialog", "Submission date"))
        self.submission_date_2.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.release_date_2.setDisplayFormat(_translate("Dialog", "yyyy-MM-dd"))
        self.label_24.setText(_translate("Dialog", "Description"))
        self.label_25.setText(_translate("Dialog", "Investigation"))
        self.identifier_2.setPlaceholderText(_translate("Dialog", "will use study identifier name from main window"))
        self.label_26.setText(_translate("Dialog", "Release date"))
        self.label_27.setText(_translate("Dialog", "Identifier"))
        self.title_2.setText(_translate("Dialog", "Investigation"))
        self.label_28.setText(_translate("Dialog", "Title"))
        self.label_29.setText(_translate("Dialog", "Investigation Contact"))
        self.pubmed_id_2.setPlaceholderText(_translate("Dialog", "e.g. 26496010"))
        self.label_32.setText(_translate("Dialog", "Status"))
        self.label_33.setText(_translate("Dialog", "Investigation Publication"))
        self.label_36.setText(_translate("Dialog", "PubMed identifier"))
        self.doi_2.setPlaceholderText(_translate("Dialog", "e.g.  10.1016/j.jhep.2013.12.002"))
        self.label_39.setText(_translate("Dialog", "Title"))
        self.label_43.setText(_translate("Dialog", "DOI"))
        self.label_52.setText(_translate("Dialog", "Authors"))
        self.label_pso_2.setText(_translate("Dialog", "connecting to PSO <sparontologies.net/ontologies/pso>"))
        self.add_contact_2.setText(_translate("Dialog", "+"))
        self.rm_contact_2.setText(_translate("Dialog", "-"))
        self.edit_contact_2.setText(_translate("Dialog", "e"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_investigation), _translate("Dialog", "Investigation"))
        self.label_44.setText(_translate("Dialog", "Characteristics *"))
        self.label_45.setText(_translate("Dialog", "Organism"))
        self.name_organism.setPlaceholderText(_translate("Dialog", "e.g. Homo sapiens"))
        self.label_46.setText(_translate("Dialog", "Organism variant"))
        self.name_organism_variant.setPlaceholderText(_translate("Dialog", "e.g. Saccharomyces cerevisiae LAN211"))
        self.name_organism_part.setPlaceholderText(_translate("Dialog", "e.g. lacrimal gland"))
        self.label_47.setText(_translate("Dialog", "Organism part"))
        self.label_50.setText(_translate("Dialog", "Protocols description *"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.extraction), _translate("Dialog", "Extraction"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_sample), _translate("Dialog", "NMR Sample"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_spec), _translate("Dialog", "NMR Spectroscopy"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.nmr_assay), _translate("Dialog", "NMR Assay"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.data_trans), _translate("Dialog", "Data transformation"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.metabo_id), _translate("Dialog", "Metabolite identification"))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.sample_collec), _translate("Dialog", "Sample collection"))
        self.search_organism.setText(_translate("Dialog", "o"))
        self.search_organism_variant.setText(_translate("Dialog", "o"))
        self.search_organism_part.setText(_translate("Dialog", "o"))
        self.accession_organism.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/VTO_0011993"))
        self.accession_organism_variant.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/NCBITaxon_1216859"))
        self.accession_organism_part.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/UBERON_0001817"))
        self.ref_organism_part.setPlaceholderText(_translate("Dialog", "e.g. UBERON"))
        self.ref_organism_variant.setPlaceholderText(_translate("Dialog", "e.g NCBITaxon"))
        self.ref_organism.setPlaceholderText(_translate("Dialog", "e.g. VTO"))
        self.rm_organism.setText(_translate("Dialog", "d"))
        self.rm_organism_variant.setText(_translate("Dialog", "d"))
        self.rm_organism_part.setText(_translate("Dialog", "d"))
        self.label_59.setText(_translate("Dialog", "Name:"))
        self.label_60.setText(_translate("Dialog", "Ref:"))
        self.label_61.setText(_translate("Dialog", "IRI:"))
        self.label_62.setText(_translate("Dialog", "IRI:"))
        self.label_63.setText(_translate("Dialog", "IRI:"))
        self.label_64.setText(_translate("Dialog", "Name:"))
        self.label_65.setText(_translate("Dialog", "Ref:"))
        self.label_66.setText(_translate("Dialog", "Name:"))
        self.label_67.setText(_translate("Dialog", "Ref:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_misc), _translate("Dialog", "Experiments"))
        self.label_70.setText(_translate("Dialog", "IRI:"))
        self.label_68.setText(_translate("Dialog", "Name:"))
        self.ref_solvent.setPlaceholderText(_translate("Dialog", "e.g. CHEBI"))
        self.search_solvent.setText(_translate("Dialog", "o"))
        self.accession_solvent.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHEBI_35702"))
        self.label_48.setText(_translate("Dialog", "Solvent"))
        self.rm_solvent.setText(_translate("Dialog", "d"))
        self.name_solvent.setPlaceholderText(_translate("Dialog", "e.g. diethyl ether"))
        self.label_69.setText(_translate("Dialog", "Ref:"))
        self.label_49.setText(_translate("Dialog", "Sample"))
        self.label_53.setText(_translate("Dialog", "Sample pH"))
        self.label_57.setText(_translate("Dialog", "NMR"))
        self.label_58.setText(_translate("Dialog", "Label"))
        self.ref_label.setPlaceholderText(_translate("Dialog", "e.g. CHEBI"))
        self.accession_label.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHEBI_33608"))
        self.rm_label.setText(_translate("Dialog", "d"))
        self.label_74.setText(_translate("Dialog", "IRI:"))
        self.label_75.setText(_translate("Dialog", "Name:"))
        self.label_76.setText(_translate("Dialog", "Ref:"))
        self.name_label.setPlaceholderText(_translate("Dialog", "e.g. hydrogen molecular entity"))
        self.search_label.setText(_translate("Dialog", "o"))
        self.label_54.setText(_translate("Dialog", "Extraction"))
        self.accession_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. http://purl.obolibrary.org/obo/CHMO_0002524"))
        self.label_55.setText(_translate("Dialog", "Extraction method (1)"))
        self.rm_extraction_method.setText(_translate("Dialog", "d"))
        self.label_77.setText(_translate("Dialog", "Ref:"))
        self.label_78.setText(_translate("Dialog", "IRI:"))
        self.search_extraction_method.setText(_translate("Dialog", "o"))
        self.ref_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. CHMO"))
        self.label_79.setText(_translate("Dialog", "Name:"))
        self.name_extraction_method.setPlaceholderText(_translate("Dialog", "e.g. Dual-phase extraction"))
        self.label_56.setText(_translate("Dialog", "(1): If no extraction method was used, put N/A in the Name field instead of leaving it blank."))
        self.label_71.setText(_translate("Dialog", "Value:"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), _translate("Dialog", "Material / Methods"))
        self.label_22.setText(_translate("Dialog", "*: Fields required by a MetaboLights study"))

import resources_rc
