# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt/ols.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(640, 480)
        Dialog.setMinimumSize(QtCore.QSize(640, 480))
        Dialog.setMaximumSize(QtCore.QSize(640, 480))
        self.buttonBox = QtWidgets.QDialogButtonBox(Dialog)
        self.buttonBox.setGeometry(QtCore.QRect(440, 445, 180, 30))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.queryLine = QtWidgets.QLineEdit(Dialog)
        self.queryLine.setGeometry(QtCore.QRect(10, 30, 511, 25))
        self.queryLine.setInputMethodHints(QtCore.Qt.ImhLatinOnly)
        self.queryLine.setClearButtonEnabled(False)
        self.queryLine.setObjectName("queryLine")
        self.labelQuery = QtWidgets.QLabel(Dialog)
        self.labelQuery.setGeometry(QtCore.QRect(10, 10, 64, 16))
        self.labelQuery.setObjectName("labelQuery")
        self.searchButton = QtWidgets.QPushButton(Dialog)
        self.searchButton.setGeometry(QtCore.QRect(540, 30, 80, 26))
        self.searchButton.setStyleSheet("font: 14pt url(:/fonts/assets/fonts/EBI-Functional.ttf);\n"
"font-family: \"EBI-Functional\";")
        self.searchButton.setDefault(True)
        self.searchButton.setObjectName("searchButton")
        self.description = QtWidgets.QTextEdit(Dialog)
        self.description.setGeometry(QtCore.QRect(390, 310, 241, 131))
        self.description.setLineWrapColumnOrWidth(0)
        self.description.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.description.setObjectName("description")
        self.ontoTree = QtWidgets.QTreeView(Dialog)
        self.ontoTree.setGeometry(QtCore.QRect(10, 100, 361, 341))
        self.ontoTree.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.ontoTree.setEditTriggers(QtWidgets.QAbstractItemView.NoEditTriggers)
        self.ontoTree.setAutoExpandDelay(0)
        self.ontoTree.setObjectName("ontoTree")
        self.labelIri = QtWidgets.QLabel(Dialog)
        self.labelIri.setGeometry(QtCore.QRect(390, 220, 64, 16))
        self.labelIri.setObjectName("labelIri")
        self.labelName = QtWidgets.QLabel(Dialog)
        self.labelName.setGeometry(QtCore.QRect(390, 80, 64, 16))
        self.labelName.setObjectName("labelName")
        self.labelPrefix = QtWidgets.QLabel(Dialog)
        self.labelPrefix.setGeometry(QtCore.QRect(390, 170, 151, 16))
        self.labelPrefix.setObjectName("labelPrefix")
        self.iri = QtWidgets.QTextEdit(Dialog)
        self.iri.setGeometry(QtCore.QRect(389, 240, 241, 41))
        self.iri.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.iri.setObjectName("iri")
        self.value = QtWidgets.QTextEdit(Dialog)
        self.value.setGeometry(QtCore.QRect(389, 100, 241, 61))
        self.value.setLineWrapColumnOrWidth(0)
        self.value.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByKeyboard|QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextBrowserInteraction|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.value.setObjectName("value")
        self.labelDescription = QtWidgets.QLabel(Dialog)
        self.labelDescription.setGeometry(QtCore.QRect(390, 290, 120, 16))
        self.labelDescription.setObjectName("labelDescription")
        self.labelResults = QtWidgets.QLabel(Dialog)
        self.labelResults.setGeometry(QtCore.QRect(10, 80, 64, 16))
        self.labelResults.setObjectName("labelResults")
        self.line = QtWidgets.QFrame(Dialog)
        self.line.setGeometry(QtCore.QRect(7, 60, 621, 20))
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.labelType = QtWidgets.QLabel(Dialog)
        self.labelType.setGeometry(QtCore.QRect(520, 170, 100, 16))
        self.labelType.setObjectName("labelType")
        self.prefix = QtWidgets.QLineEdit(Dialog)
        self.prefix.setGeometry(QtCore.QRect(390, 190, 121, 25))
        self.prefix.setReadOnly(True)
        self.prefix.setObjectName("prefix")
        self.type = QtWidgets.QLineEdit(Dialog)
        self.type.setGeometry(QtCore.QRect(520, 190, 110, 25))
        self.type.setReadOnly(True)
        self.type.setObjectName("type")

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Ontology Lookup Service"))
        self.queryLine.setPlaceholderText(_translate("Dialog", "e.g. Mus Musculus,  spleen primordium, rhodopsin..."))
        self.labelQuery.setText(_translate("Dialog", "Query"))
        self.searchButton.setText(_translate("Dialog", "1"))
        self.labelIri.setText(_translate("Dialog", "IRI"))
        self.labelName.setText(_translate("Dialog", "Name"))
        self.labelPrefix.setText(_translate("Dialog", "Ontology Prefix"))
        self.labelDescription.setText(_translate("Dialog", "Description"))
        self.labelResults.setText(_translate("Dialog", "Results"))
        self.labelType.setText(_translate("Dialog", "Item Type"))

import resources_rc
